@@ -9,7 +9,10 @@ fn test_hoi4_text() -> Result<(), Box<dyn Error>> {
     let (save, encoding) = Hoi4Extractor::builder().extract_save(&data)?;
     assert_eq!(encoding, Encoding::Plaintext);
     assert_eq!(save.player, String::from("FRA"));
-    assert_eq!(save.date.game_fmt().to_string(), String::from("1936.1.1.12"));
+    assert_eq!(
+        save.date.game_fmt().to_string(),
+        String::from("1936.1.1.12")
+    );
     Ok(())
 }
 
@@ -20,7 +23,10 @@ fn test_hoi4_normal_bin() -> Result<(), Box<dyn Error>> {
     let (save, encoding) = Hoi4Extractor::builder().extract_save(&data)?;
     assert_eq!(encoding, Encoding::Binary);
     assert_eq!(save.player, String::from("FRA"));
-    assert_eq!(save.date.game_fmt().to_string(), String::from("1936.1.1.12"));
+    assert_eq!(
+        save.date.game_fmt().to_string(),
+        String::from("1936.1.1.12")
+    );
     Ok(())
 }
 
@@ -31,7 +37,10 @@ fn test_hoi4_ironman() -> Result<(), Box<dyn Error>> {
     let (save, encoding) = Hoi4Extractor::builder().extract_save(&data)?;
     assert_eq!(encoding, Encoding::Binary);
     assert_eq!(save.player, String::from("FRA"));
-    assert_eq!(save.date.game_fmt().to_string(), String::from("1936.1.1.12"));
+    assert_eq!(
+        save.date.game_fmt().to_string(),
+        String::from("1936.1.1.12")
+    );
     Ok(())
 }
 
@@ -47,7 +56,10 @@ fn test_normal_roundtrip() -> Result<(), Box<dyn Error>> {
     let (save, encoding) = Hoi4Extractor::builder().extract_save(&melted)?;
     assert_eq!(encoding, Encoding::Plaintext);
     assert_eq!(save.player, String::from("FRA"));
-    assert_eq!(save.date.game_fmt().to_string(), String::from("1936.1.1.12"));
+    assert_eq!(
+        save.date.game_fmt().to_string(),
+        String::from("1936.1.1.12")
+    );
     Ok(())
 }
 
@@ -63,6 +75,9 @@ fn test_ironman_roundtrip() -> Result<(), Box<dyn Error>> {
     let (save, encoding) = Hoi4Extractor::builder().extract_save(&melted)?;
     assert_eq!(encoding, Encoding::Plaintext);
     assert_eq!(save.player, String::from("FRA"));
-    assert_eq!(save.date.game_fmt().to_string(), String::from("1936.1.1.12"));
+    assert_eq!(
+        save.date.game_fmt().to_string(),
+        String::from("1936.1.1.12")
+    );
     Ok(())
 }
